==> asteg-0.1.4.tar.gz: asteg-0.1.4/setup.py <==
from setuptools import setup
from asteg import __version__

def read_file(filename,lines=False):
    try:
        with open(filename, 'r', encoding='utf-8') as f:
            if(lines):
                return [i.strip() for i in f.readlines() if(i.strip())]
            return f.read()
    except:
        return None

requirements = read_file('requirements.txt', lines=True)
long_description = read_file('README.md')

setup(
    name='asteg',
    version=__version__,
    
    author='Ibrahim Rafi',
    author_email='me@ibrahimrafi.me',

    license='MIT',

    url='https://github.com/rafiibrahim8/asteg',
    download_url = 'https://github.com/rafiibrahim8/asteg/archive/v{}.tar.gz'.format(__version__),

    install_requires=requirements,

    description='Steganography : Hiding text or file inside an audio',
    long_description=long_description,
    long_description_content_type='text/markdown',
    keywords=['asteg', 'steganography', 'audio'],

    packages=["asteg"],
    entry_points=dict(
        console_scripts=[
            'asteg=asteg.asteg_cli:main'
        ]
    ),

    platforms=['any'],
    classifiers=[
    'Development Status :: 3 - Alpha',
    'Intended Audience :: Science/Research',
    'Topic :: Security :: Cryptography',
    'License :: OSI Approved :: MIT License',
    'Programming Language :: Python :: 3',
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
    'Programming Language :: Python :: 3.7',
    'Programming Language :: Python :: 3.8',
    'Programming Language :: Python :: 3.9',
  ],
)

==> asteg-0.1.5.tar.gz: asteg-0.1.5/setup.py <==
from setuptools import setup
from asteg import __version__

def read_file(filename,lines=False):
    try:
        with open(filename, 'r', encoding='utf-8') as f:
            if(lines):
                return [i.strip() for i in f.readlines() if(i.strip())]
            return f.read()
    except:
        return None

requirements = read_file('requirements.txt', lines=True) #this does not works when installing from pypi
long_description = read_file('README.md')

setup(
    name='asteg',
    version=__version__,
    
    author='Ibrahim Rafi',
    author_email='me@ibrahimrafi.me',

    license='MIT',

    url='https://github.com/rafiibrahim8/asteg',
    download_url = 'https://github.com/rafiibrahim8/asteg/archive/v{}.tar.gz'.format(__version__),

    install_requires= ['pydub', 'numpy', 'scipy'],

    description='Steganography : Hiding text or file inside an audio',
    long_description=long_description,
    long_description_content_type='text/markdown',
    keywords=['asteg', 'steganography', 'audio'],

    packages=["asteg"],
    entry_points=dict(
        console_scripts=[
            'asteg=asteg.asteg_cli:main'
        ]
    ),

    platforms=['any'],
    classifiers=[
    'Development Status :: 3 - Alpha',
    'Intended Audience :: Science/Research',
    'Topic :: Security :: Cryptography',
    'License :: OSI Approved :: MIT License',
    'Programming Language :: Python :: 3',
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
    'Programming Language :: Python :: 3.7',
    'Programming Language :: Python :: 3.8',
    'Programming Language :: Python :: 3.9',
  ],
)
